@@ -1,7 +1,7 @@
 /*
   kcmdf.h - KDiskFree
 
-  written 1999 by Michael Kropfberger <michael.kropfberger@gmx.net>
+  Copyright (C) 1999 by Michael Kropfberger <michael.kropfberger@gmx.net>
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    
   */
 
@@ -38,8 +38,9 @@ class KDiskFreeWidget : public KCModule
     KDiskFreeWidget( QWidget *parent=0, const char *name=0 );
     ~KDiskFreeWidget();
 
+    QString quickHelp() const;
+
   private:
-    QFrame *mPage;
     KDFWidget *mKdf;
     KDFConfigWidget *mMcw;
     MntConfigWidget *mKcw;
